==> ejc-procurement-api-3.0.0-20251212.073326-106-sources.jar: com/ejianc/business/procurement/perform/vo/PurchaseProjectSupplierVO.java <==
package com.ejianc.business.procurement.perform.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 采购项目-供应商寻源情况
 * 
 * @author generator
 * 
 */
public class PurchaseProjectSupplierVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long pid; // 主表主键
    private String bodyMemo; // 备注
    private Integer inCooperate; // 是否合作
    private Integer inStore; // 是否在库
    private String telephone; // 联系方式
    private String linkerName; // 联系人
    private String socialCreditCode; // 统一社会信用代码证
    private String supplierName; // 供应商名称
    private String supplierCode; // 供应商编码
    private Long supplierId; // 供应商id
    

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public String getBodyMemo() {
        return bodyMemo;
    }

    public void setBodyMemo(String bodyMemo) {
        this.bodyMemo = bodyMemo;
    }
    public Integer getInCooperate() {
        return inCooperate;
    }

    public void setInCooperate(Integer inCooperate) {
        this.inCooperate = inCooperate;
    }
    public Integer getInStore() {
        return inStore;
    }

    public void setInStore(Integer inStore) {
        this.inStore = inStore;
    }
    public String getTelephone() {
        return telephone;
    }

    public void setTelephone(String telephone) {
        this.telephone = telephone;
    }
    public String getLinkerName() {
        return linkerName;
    }

    public void setLinkerName(String linkerName) {
        this.linkerName = linkerName;
    }
    public String getSocialCreditCode() {
        return socialCreditCode;
    }

    public void setSocialCreditCode(String socialCreditCode) {
        this.socialCreditCode = socialCreditCode;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public String getSupplierCode() {
        return supplierCode;
    }

    public void setSupplierCode(String supplierCode) {
        this.supplierCode = supplierCode;
    }
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    
}

==> ejc-procurement-api-3.0.0-20251216.073623-135-sources.jar: com/ejianc/business/procurement/perform/vo/PurchaseProjectSupplierVO.java <==
package com.ejianc.business.procurement.perform.vo;

import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 采购项目-供应商寻源情况
 * 
 * @author generator
 * 
 */
public class PurchaseProjectSupplierVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long pid; // 主表主键
    private String bodyMemo; // 备注
    private Integer inCooperate; // 是否合作
    private Integer inStore; // 是否在库
    private String telephone; // 联系方式
    private String linkerName; // 联系人
    private String socialCreditCode; // 统一社会信用代码
    private String supplierName; // 供应商名称
    private String supplierCode; // 供应商编码
    private Long supplierId; // 供应商id
    

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public String getBodyMemo() {
        return bodyMemo;
    }

    public void setBodyMemo(String bodyMemo) {
        this.bodyMemo = bodyMemo;
    }
    public Integer getInCooperate() {
        return inCooperate;
    }

    public void setInCooperate(Integer inCooperate) {
        this.inCooperate = inCooperate;
    }
    public Integer getInStore() {
        return inStore;
    }

    public void setInStore(Integer inStore) {
        this.inStore = inStore;
    }
    public String getTelephone() {
        return telephone;
    }

    public void setTelephone(String telephone) {
        this.telephone = telephone;
    }
    public String getLinkerName() {
        return linkerName;
    }

    public void setLinkerName(String linkerName) {
        this.linkerName = linkerName;
    }
    public String getSocialCreditCode() {
        return socialCreditCode;
    }

    public void setSocialCreditCode(String socialCreditCode) {
        this.socialCreditCode = socialCreditCode;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public String getSupplierCode() {
        return supplierCode;
    }

    public void setSupplierCode(String supplierCode) {
        this.supplierCode = supplierCode;
    }
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    
}
